==> owlapi-impl-4.5.24-sources.jar: org/semanticweb/owlapi/reasoner/impl/OWLDatatypeNode.java <==
/* This file is part of the OWL API.
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * Copyright 2014, The University of Manchester
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. */
package org.semanticweb.owlapi.reasoner.impl;

import java.util.Set;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import org.semanticweb.owlapi.model.OWLDatatype;

/**
 * @author Matthew Horridge, The University of Manchester, Information
 *         Management Group
 * @since 3.0.0
 */
public class OWLDatatypeNode extends DefaultNode<OWLDatatype> {

    /** default constructor. */
    public OWLDatatypeNode() {}

    /**
     * @param entity
     *        datatype to include
     */
    public OWLDatatypeNode(@Nonnull OWLDatatype entity) {
        super(entity);
    }

    /**
     * @param entities
     *        set of datatypes to include
     */
    public OWLDatatypeNode(@Nonnull Set<OWLDatatype> entities) {
        super(entities);
    }

    @Override
    protected OWLDatatype getTopEntity() {
        return TOP_DATATYPE;
    }

    @Nullable
    @Override
    protected OWLDatatype getBottomEntity() {
        return null;
    }
}

==> owlapi-impl-5.0.5-sources.jar: org/semanticweb/owlapi/reasoner/impl/OWLDatatypeNode.java <==
/* This file is part of the OWL API.
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * Copyright 2014, The University of Manchester
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. */
package org.semanticweb.owlapi.reasoner.impl;

import java.util.Collection;
import java.util.Optional;
import java.util.stream.Stream;

import org.semanticweb.owlapi.model.OWLDatatype;

/**
 * @author Matthew Horridge, The University of Manchester, Information
 *         Management Group
 * @since 3.0.0
 */
public class OWLDatatypeNode extends DefaultNode<OWLDatatype> {

    /** Default constructor. */
    public OWLDatatypeNode() {
        super();
    }

    /**
     * @param entity
     *        datatype to include
     */
    public OWLDatatypeNode(OWLDatatype entity) {
        super(entity);
    }

    /**
     * @param entities
     *        set of datatypes to include
     */
    public OWLDatatypeNode(Collection<OWLDatatype> entities) {
        super(entities);
    }

    /**
     * @param entities
     *        set of datatypes to include
     */
    public OWLDatatypeNode(Stream<OWLDatatype> entities) {
        super(entities);
    }

    @Override
    protected Optional<OWLDatatype> getTopEntity() {
        return Optional.of(TOP_DATATYPE);
    }

    @Override
    protected Optional<OWLDatatype> getBottomEntity() {
        return Optional.empty();
    }
}
